@@ -34,13 +34,15 @@
 #include <libgnome/gnome-i18n.h>
 #include <libgnomeui/gnome-dialog.h>
 #include <libgnomeprint/gnome-print.h>
+#include <libgnomeprint/gnome-print-unit.h>
+#include <libgnomeprint/gnome-print-config.h>
 #include <libgnomeprint/gnome-font.h>
 #include <libgnomeprint/gnome-print-job.h>
 #include <libgnomeprintui/gnome-print-dialog.h>
 #include <libgnomeprintui/gnome-print-job-preview.h>
 #include <libebook/e-book.h>
 #include <libebook/e-contact.h>
-#include <gal/util/e-util.h>
+#include <e-util/e-util.h>
 #include <e-util/e-print.h>
 
 #define SCALE 5
@@ -714,10 +716,11 @@ static void get_font( char *data, GnomeFont **variable )
 
 
 static void
-e_contact_build_style(EContactPrintStyle *style)
+e_contact_build_style(EContactPrintStyle *style, GnomePrintConfig *config)
 {
 	xmlDocPtr styledoc;
 	gchar *filename;
+	gdouble page_height, page_width;
 
 	style->title = g_strdup("");
 	style->type = E_CONTACT_PRINT_TYPE_CARDS;
@@ -845,6 +848,15 @@ e_contact_build_style(EContactPrintStyle *style)
 		}
 		xmlFreeDoc(styledoc);
 	}
+
+	/*
+	 * get paper size and set it to the print style
+	 */
+	gnome_print_config_get_page_size(config, &page_width, &page_height);
+	gnome_print_convert_distance(&page_width, gnome_print_unit_get_default(), gnome_print_unit_get_by_name("Inches"));
+	gnome_print_convert_distance(&page_height, gnome_print_unit_get_default(), gnome_print_unit_get_by_name("Inches"));
+	style->page_height = page_height;
+	style->page_width = page_width;
 }
 
 static gint
@@ -861,8 +873,19 @@ e_contact_print_response(GtkWidget *dialog, gint response_id, gpointer data)
 	GnomePrintJob *master;
 	GnomePrintConfig *config;
 	GnomePrintContext *pc;
-	gboolean uses_book = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(dialog), "uses_book"));
-	gboolean uses_list = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(dialog), "uses_list"));
+	gboolean uses_book = FALSE, uses_list = FALSE, uses_range = FALSE;
+
+	uses_range = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (dialog), "uses_range"));
+	if (uses_range) {
+		if (gnome_print_dialog_get_range (GNOME_PRINT_DIALOG (dialog)) & GNOME_PRINT_RANGE_ALL)
+			uses_book = TRUE;
+		if (gnome_print_dialog_get_range (GNOME_PRINT_DIALOG (dialog)) & GNOME_PRINT_RANGE_SELECTION)
+			uses_list = TRUE;
+	}
+	else {
+		uses_book = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (dialog), "uses_book"));
+		uses_list = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (dialog), "uses_list"));
+	}
 	EBook *book = NULL;
 	EBookQuery *query = NULL;
 	EContact *contact = NULL;
@@ -885,7 +908,7 @@ e_contact_print_response(GtkWidget *dialog, gint response_id, gpointer data)
 		config = gnome_print_dialog_get_config (GNOME_PRINT_DIALOG(dialog));
 		master = gnome_print_job_new( config );
 		pc = gnome_print_job_get_context( master );
-		e_contact_build_style(style);
+		e_contact_build_style(style, config);
 		
 		ctxt->x = 0;
 		ctxt->y = 0;
@@ -931,7 +954,7 @@ e_contact_print_response(GtkWidget *dialog, gint response_id, gpointer data)
 		config = gnome_print_dialog_get_config (GNOME_PRINT_DIALOG(dialog));
 		master = gnome_print_job_new( config );
 		pc = gnome_print_job_get_context( master );
-		e_contact_build_style(style);
+		e_contact_build_style(style, config);
 		
 		ctxt->x = 0;
 		ctxt->y = 0;
@@ -993,20 +1016,27 @@ e_contact_print_response(GtkWidget *dialog, gint response_id, gpointer data)
 }
 
 GtkWidget *
-e_contact_print_dialog_new(EBook *book, char *query)
+e_contact_print_dialog_new(EBook *book, char *query, GList *list)
 {
 	GtkWidget *dialog;
+	GList *copied_list = NULL;
+	GList *l;
 	
 	
 	dialog = e_print_get_dialog(_("Print contacts"), GNOME_PRINT_DIALOG_RANGE | GNOME_PRINT_DIALOG_COPIES);
 	gnome_print_dialog_construct_range_any(GNOME_PRINT_DIALOG(dialog), GNOME_PRINT_RANGE_ALL | GNOME_PRINT_RANGE_SELECTION,
 					       NULL, NULL, NULL);
 
+	if (list != NULL) {
+		copied_list = g_list_copy (list);
+		for (l = copied_list; l; l = l->next)
+			l->data = e_contact_duplicate (E_CONTACT (l->data));
+	}
 	g_object_ref(book);
-	g_object_set_data(G_OBJECT(dialog), "uses_book", GINT_TO_POINTER (TRUE));
-	g_object_set_data(G_OBJECT(dialog), "uses_list", GINT_TO_POINTER (FALSE));
+	g_object_set_data(G_OBJECT(dialog), "contact_list", copied_list);
 	g_object_set_data(G_OBJECT(dialog), "book", book);
 	g_object_set_data(G_OBJECT(dialog), "query", e_book_query_from_string  (query));
+	g_object_set_data(G_OBJECT(dialog), "uses_range", GINT_TO_POINTER (TRUE));
 	g_signal_connect(dialog,
 			 "response", G_CALLBACK(e_contact_print_response), NULL);
 	g_signal_connect(dialog,
@@ -1015,7 +1045,7 @@ e_contact_print_dialog_new(EBook *book, char *query)
 }
 
 void
-e_contact_print_preview(EBook *book, char *query)
+e_contact_print_preview(EBook *book, char *query, GList *list)
 {
 	EContactPrintContext *ctxt = g_new(EContactPrintContext, 1);
 	EContactPrintStyle *style = g_new(EContactPrintStyle, 1);
@@ -1023,11 +1053,23 @@ e_contact_print_preview(EBook *book, char *query)
 	GnomePrintContext *pc;
 	GnomePrintConfig *config;
 	gdouble font_size;
+	GList *copied_list = NULL;
+	GList *l;
+	gboolean uses_book = FALSE, uses_list = FALSE;
 
 	config = e_print_load_config ();
 	master = gnome_print_job_new (config);
 	pc = gnome_print_job_get_context (master);
-	e_contact_build_style (style);
+	e_contact_build_style (style, config);
+
+	if (list == NULL) 
+		uses_book = TRUE;
+	else {
+		uses_list = TRUE;
+		copied_list = g_list_copy (list);
+		for (l = copied_list; l; l = l->next)
+			l->data = e_contact_duplicate (E_CONTACT (l->data));
+	}
 
 	ctxt->x = 0;
 	ctxt->y = 0;
@@ -1053,9 +1095,17 @@ e_contact_print_preview(EBook *book, char *query)
 #endif
 	ctxt->book = book;
 	ctxt->query = e_book_query_from_string (query);
-	ctxt->contacts = NULL;
-	g_object_ref(book);
-	e_contact_do_print(book, ctxt->query, ctxt);
+
+	if (uses_book) {
+		ctxt->contacts = NULL;
+		g_object_ref (book);
+		e_contact_do_print (book, ctxt->query, ctxt);
+	}
+	else if (uses_list) {
+		ctxt->contacts = g_list_copy (copied_list);
+		g_list_foreach (ctxt->contacts, (GFunc) g_object_ref, NULL);
+		complete_sequence (NULL, E_BOOK_VIEW_STATUS_OK, ctxt);
+	}
 }
 
 GtkWidget *
@@ -1069,6 +1119,7 @@ e_contact_print_contact_dialog_new(EContact *contact)
 	g_object_set_data(G_OBJECT(dialog), "contact", contact);
 	g_object_set_data(G_OBJECT(dialog), "uses_list", GINT_TO_POINTER (FALSE));
 	g_object_set_data(G_OBJECT(dialog), "uses_book", GINT_TO_POINTER (FALSE));
+	g_object_set_data(G_OBJECT(dialog), "uses_range", GINT_TO_POINTER (FALSE));
 	g_signal_connect(dialog,
 			 "response", G_CALLBACK(e_contact_print_response), NULL);
 	g_signal_connect(dialog,
@@ -1095,6 +1146,7 @@ e_contact_print_contact_list_dialog_new(GList *list)
 	g_object_set_data(G_OBJECT(dialog), "contact_list", copied_list);
 	g_object_set_data(G_OBJECT(dialog), "uses_list", GINT_TO_POINTER (TRUE));
 	g_object_set_data(G_OBJECT(dialog), "uses_book", GINT_TO_POINTER (FALSE));
+	g_object_set_data(G_OBJECT(dialog), "uses_range", GINT_TO_POINTER (FALSE));
 	g_signal_connect(dialog,
 			 "response", G_CALLBACK(e_contact_print_response), NULL);
 	g_signal_connect(dialog,
