@@ -96,7 +96,7 @@ cal_comp_util_compare_event_timezones (ECalComponent *comp,
 				       ECal *client,
 				       icaltimezone *zone)
 {
-	ECalComponentDateTime start_datetime, end_datetime;
+	ECalComponentDateTime start_datetime = {0}, end_datetime = {0};
 	const char *tzid;
 	gboolean retval = FALSE;
 	icaltimezone *start_zone, *end_zone;
@@ -256,13 +256,13 @@ cal_comp_event_new_with_defaults (ECal *client)
 	ECalComponentAlarmTrigger trigger;
 
 	if (!e_cal_get_default_object (client, &icalcomp, NULL))
-		return NULL;
+		icalcomp = icalcomponent_new (ICAL_VEVENT_COMPONENT);
 
 	comp = e_cal_component_new ();
 	if (!e_cal_component_set_icalcomponent (comp, icalcomp)) {
-		g_object_unref (comp);
 		icalcomponent_free (icalcomp);
-		return NULL;
+
+		e_cal_component_set_new_vtype (comp, E_CAL_COMPONENT_EVENT);
 	}
 	
 	if (!calendar_config_get_use_default_reminder ())
@@ -348,8 +348,6 @@ cal_comp_event_new_with_current_time (ECal *client, gboolean all_day)
 		e_cal_component_set_dtend (comp, &dt);
 	}
 
-	e_cal_component_commit_sequence (comp);
-
 	return comp;
 }
 
@@ -360,21 +358,13 @@ cal_comp_task_new_with_defaults (ECal *client)
 	icalcomponent *icalcomp;
 
 	if (!e_cal_get_default_object (client, &icalcomp, NULL))
-		return NULL;
-
+		icalcomp = icalcomponent_new (ICAL_VTODO_COMPONENT);
+	
 	comp = e_cal_component_new ();
 	if (!e_cal_component_set_icalcomponent (comp, icalcomp)) {
-		g_object_unref (comp);
 		icalcomponent_free (icalcomp);
 
-		return NULL;
-	}
-
-	comp = e_cal_component_new ();
-	if (!e_cal_component_set_icalcomponent (comp, icalcomp)) {
-		g_object_unref (comp);
-		icalcomponent_free (icalcomp);
-		return NULL;
+		e_cal_component_set_new_vtype (comp, E_CAL_COMPONENT_TODO);
 	}
 
 	return comp;
