@@ -34,8 +34,8 @@
 #include <libgnomeui/gnome-file-entry.h>
 
 #include "filter-file.h"
-#include "e-util/e-sexp.h"
-#include "widgets/misc/e-error.h"
+#include "libedataserver/e-sexp.h"
+#include "e-util/e-error.h"
 
 #define d(x)
 
