@@ -363,8 +363,8 @@ setup_fields (ETableConfig *config)
 {
 	int i;
 
-	e_table_model_freeze (config->available_model);
-	e_table_model_freeze (config->shown_model);
+	e_table_model_freeze ((ETableModel *)config->available_model);
+	e_table_model_freeze ((ETableModel *)config->shown_model);
 	e_table_without_show_all (config->available_model);
 	e_table_subset_variable_clear (config->shown_model);
 
@@ -379,8 +379,8 @@ setup_fields (ETableConfig *config)
 			e_table_without_hide (config->available_model, GINT_TO_POINTER(idx));
 		}
 	}
-	e_table_model_thaw (config->available_model);
-	e_table_model_thaw (config->shown_model);
+	e_table_model_thaw ((ETableModel *)config->available_model);
+	e_table_model_thaw ((ETableModel *)config->shown_model);
 }
 
 static void
